@@ -63,7 +63,7 @@ static int _parse_param_quoted(struct vparse_state *state, int multiparam)
             INC(1);
             return 0;
 
-        /* normal backslash quoting - NOTE, not strictly RFC complient,
+        /* normal backslash quoting - NOTE, not strictly RFC compliant,
          * but I figure anyone who generates one PROBABLY meant to escape
          * the next character because it's so common, and LABEL definitely
          * allows \n, so we have to handle that anyway */
@@ -124,6 +124,7 @@ static int _parse_param_quoted(struct vparse_state *state, int multiparam)
             if (multiparam)
                 return PE_QSTRING_COMMA;
             /* or fall through, comma isn't special */
+            GCC_FALLTHROUGH
 
         default:
             PUTC(*state->p);
@@ -312,6 +313,7 @@ repeat:
                 break;
             }
             /* or fall through, comma isn't special */
+            GCC_FALLTHROUGH
 
         default:
             PUTC(*state->p);
